import setuptools

setuptools.setup(
	name='vvv11inf35706',
	version='1.0',
	author='vvv06357',
	author_email='valery.ovechey@gmail.com',
	description='flskdzhgby',
	packages=['vvv11inf35706'],
	classifiers=[
		"Programming Language :: Python :: 3",
		"License :: OSI Approved :: MIT License",
		"Operating System :: OS Independent",
	],
	python_requires='>=3.6',
)